@@ -128,25 +128,23 @@ void fill_window(Display *display, int victim, int w, int h)
 void my_kill(int pid)
 {
      int status;
+
      if(!kill(pid, SIGTERM))
      {
-	  D("killing %d\n", pid);
+	  D("Killing PID %d with SIGTERM\n", pid);
 	  usleep(4000);
 	  if(!kill(pid, SIGTERM))
 	  {
-	       /* We have failed to kill our children twice,
-		* sleep on it and try again tomorrow..
-		*/
+   	       D("Killing PID %d with SIGTERM\n", pid);
 	       usleep(4000);
 	       if(!kill(pid, SIGTERM))
 	       {
-		    /* We have failed to kill our children a third time -
-		     * wield nukes and try again.
-		     */
+		    D("Killing PID %d with SIGKILL\n", pid);
 		    kill(pid, SIGKILL);
 	       }
 	  }
      }
-     D("Waiting sons\n");
+
+     D("Waiting for sons\n");
      while (waitpid(-1, &status, WNOHANG) > 0);
 }
