@@ -66,7 +66,7 @@ void redraw()
 {
   static int old_buttonsize = -1;
   XWindowAttributes attr;
-  XPoint points[5];
+  XPoint points[6];
 
   if(windowed && state == STATE_PLAY) return;
 
@@ -210,6 +210,8 @@ int main(int argc, char **argv)
   XSetWindowAttributes attr;
   XSizeHints wmHints;
 
+  if (argc < 2) exit(0);
+
   if(!(dpy = XOpenDisplay(getenv("DISPLAY"))))
   {
     fprintf(stderr,"%s: unable to open display %s\n",
@@ -228,8 +230,6 @@ int main(int argc, char **argv)
   wmHints.base_height = 20;
   wmHints.flags=PPosition | USPosition | PMinSize;
 
-
-
   attr.border_pixel = 0; 
   attr.background_pixel = WhitePixelOfScreen(DefaultScreenOfDisplay(dpy));
   attr.event_mask = ExposureMask;
@@ -247,6 +247,11 @@ int main(int argc, char **argv)
 			    CWBackPixel),
 			   &attr);
 
+  classhint.res_name = "mozplugger-controller";
+  classhint.res_class = "mozplugger-controller";
+  XSetClassHint(dpy, topLevel, &classhint);
+  XStoreName(dpy, topLevel, "mozplugger-controller");
+
   gc_black=XCreateGC(dpy,topLevel,0,0);
   XSetForeground(dpy,gc_black,BlackPixel(dpy,DefaultScreen(dpy)));
 
@@ -265,12 +270,6 @@ int main(int argc, char **argv)
 
   XSetWMNormalHints(dpy, topLevel, &wmHints);
 
-  classhint.res_name = "mozplugger-controller";
-  classhint.res_class = "mozplugger-controller";
-  XSetClassHint(dpy, topLevel, &classhint);
-
-  XMapRaised(dpy, topLevel);
-
   XSetIOErrorHandler(die2);
   XSetErrorHandler(die);
 
