@@ -251,42 +251,36 @@ static int event_swallow()
      D("Looking for victim... (%s)\n", victimname);
      /* XCheckMaskEvent is a non-blocking call, go through all
 	waiting SubStructureEvents, untill we're out of them. */
-     while (XCheckMaskEvent(display,SubstructureNotifyMask,&evt))
+     while (XCheckMaskEvent(display, SubstructureNotifyMask, &evt))
      {
 	  /* got a structure event */
 	  D("Got Structure Event of type %x\n", evt.type);
 	  if (evt.type == CreateNotify)
 	  {
-		  
 	       /* looks promising, let's see if it's the one we're looking for */
 	       D("Found CreateNotify Event %x\n", evt.type);
 
-	       if (!XGetClassHint(display, evt.xcreatewindow.window, &windowclass))
+	       if (XFetchName(display, evt.xcreatewindow.window, &windowname))
 	       {
-		    D("Could Not get Class Hint, trying the next one");
-		    continue;
-	       }
-
-	       if (!XFetchName(display, evt.xcreatewindow.window, &windowname))
-	       {
-		    D("Could Not Get Window Name, trying the next one");
-		    continue;
-	       }
-
-	       if (windowname)
-	       {
-		    D("Victim Name is :%s\n", victimname);
-		    D("Window Name is :%s\n", windowname);
-		    len = strlen(victimname);
-		    if (strncmp(victimname, windowname, len) == 0 ||
-			strncmp(victimname, windowclass.res_class, len) == 0 ||
-			strncmp(victimname, windowclass.res_name, len) == 0)
+		    if (XGetClassHint(display, evt.xcreatewindow.window, &windowclass))
 		    {
-			 victim = evt.xcreatewindow.window;
-			 found = 1;
-			 D("Found it!! Victim=%x\n", victim);
-			 D("Flags %x\n", flags);
-			 place_window();
+			 D("Window Name: %s\n", windowname);
+			 D("Class Name: %s\n", windowclass.res_class);
+			 D("Class Name: %s\n", windowclass.res_name);
+			 
+			 len = strlen(victimname);
+			 if (strncmp(victimname, windowname, len) == 0 ||
+			     strncmp(victimname, windowclass.res_class, len) == 0 ||
+			     strncmp(victimname, windowclass.res_name, len) == 0)
+			 {
+			      victim = evt.xcreatewindow.window;
+			      found = 1;
+			      D("Found it!! Victim=%x\n", victim);
+			      D("Flags %x\n", flags);
+			      place_window();
+			 }
+			 XFree(windowclass.res_class);
+			 XFree(windowclass.res_name);
 		    }
 		    XFree(windowname);
 	       }
@@ -321,6 +315,7 @@ static int init_swallow()
      {
           if (!XSelectInput(display, DefaultRootWindow(display), SubstructureNotifyMask))
 	       return 1;
+	  XSync(display, FALSE);
      }
      else
      {
