@@ -377,7 +377,7 @@ static int parse_flags(char **x, command_t *commandp)
 	  }
 	  if (match(*x, "controls"))
 	  {
-	       commandp->flags |= H_CONTROLS | H_SWALLOW | H_FILL;
+	       commandp->flags |= H_CONTROLS | H_EVENT_SWALLOW | H_FILL;
 	       commandp->winname = strdup("mozplugger-controller");
 	       *x += 8;
 	       return 1;
@@ -889,8 +889,7 @@ NPError NPP_New(NPMIMEType pluginType,
 	  D("VAR_%s=%s\n", argn[e], argv[e]);
 	  if (!(THIS->args[e].var = (char *)malloc(strlen(argn[e]) + 5)))
 	       return NPERR_OUT_OF_MEMORY_ERROR;
-	  memcpy(THIS->args[e].var, "VAR_", 4);
-	  memcpy(THIS->args[e].var+4, argn[e], strlen(argn[e])+1);
+	  sprintf(THIS->args[e].var, "VAR_%s", argn[e]);
 	  THIS->args[e].value = argv[e] ? strdup(argv[e]) : NULL;
      }
 
@@ -938,7 +937,7 @@ NPError NPP_Destroy(NPP instance, NPSavedData** save)
 
      if (THIS)
      {
-	  /* Kill the mozplugger process and his sons */
+	  /* Kill the mozplugger-helper process and his sons */
  	  if (THIS->pid > 0)
 	       my_kill(-THIS->pid);
 
